@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 5 / Imagick											  |
    +----------------------------------------------------------------------+
-   | Copyright (c) 2006-2009 Mikko Koppanen, Scott MacVicar				  |
+   | Copyright (c) 2006-2013 Mikko Koppanen, Scott MacVicar				  |
    | Imagemagick (c) ImageMagick Studio LLC								  |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,	  |
@@ -68,9 +68,13 @@ zend_bool php_imagick_thumbnail_dimensions(MagickWand *magick_wand, zend_bool be
 
 		ratio_x = (double)desired_width / (double)orig_width; 
 		ratio_y = (double)desired_height / (double)orig_height; 
-		
-		if (ratio_x < ratio_y) { 
-			*new_width  = desired_width; 
+
+		//in the case of square images there should be no rounding error
+		if (ratio_x == ratio_y) {
+			*new_width  = desired_width;
+			*new_height = desired_height;
+		} else if (ratio_x < ratio_y) { 
+			*new_width  = desired_width;
 			*new_height = ratio_x * (double)orig_height; 
 		} else { 
 			*new_height = desired_height; 
@@ -115,7 +119,7 @@ zend_bool php_imagick_resize_bounding_box(MagickWand *magick_wand, long box_widt
 {
 	long new_width, new_height;
 	long extent_x, extent_y;
-	
+
 	/* Calculate dimensions */
 	if (!php_imagick_thumbnail_dimensions(magick_wand, 1, box_width, box_height, &new_width, &new_height)) {
 		return 0;
@@ -130,237 +134,18 @@ zend_bool php_imagick_resize_bounding_box(MagickWand *magick_wand, long box_widt
 	if (!fill) {
 		return 1;
 	}
-	
+
 	/* In case user wants to fill use extent for it rather than creating a new canvas */
 	extent_x = (box_width > new_width)   ? ((box_width - new_width) / 2)   : 0;
 	extent_y = (box_height > new_height) ? ((box_height - new_height) / 2) : 0;
 
-	if (MagickExtentImage(magick_wand, box_width, box_height, extent_x, extent_y) == MagickFalse) {
+	if (MagickExtentImage(magick_wand, box_width, box_height, extent_x * -1, extent_y * -1) == MagickFalse) {
 		return 0;
 	}
 	return 1;
 }
 #endif
 
-/*
-	type 1 = MagickWriteImageFile
-	type 2 = MagickWriteImagesFile
-	
-	type 3 = MagickReadImageFile
-	type 4 = MagickPingImageFile
-
-	return values:
-		0 - no error
-		1 - error and exception has been thrown
-		2 - error but exception needs to be thrown
-*/
-int php_imagick_stream_handler(php_imagick_object *intern, php_stream *stream, char *filename, int type TSRMLS_DC)
-{
-#if ZEND_MODULE_API_NO > 20060613 
-	zend_error_handling error_handling;
-#endif
-	FILE *fp;
-	MagickBooleanType status = MagickFalse;
-
-#if ZEND_MODULE_API_NO > 20060613 
-	zend_replace_error_handling(EH_THROW, php_imagick_exception_class_entry, &error_handling TSRMLS_CC);
-#else
-	php_set_error_handling(EH_THROW, php_imagick_exception_class_entry TSRMLS_CC);
-#endif	
-
-	if (php_stream_can_cast(stream, PHP_STREAM_AS_STDIO | PHP_STREAM_CAST_INTERNAL) == FAILURE) {
-		goto return_on_error;
-	}
-
-	if (php_stream_cast(stream, PHP_STREAM_AS_STDIO | PHP_STREAM_CAST_INTERNAL, (void*)&fp, 0) == FAILURE) {
-		goto return_on_error;
-	}
-	
-#if ZEND_MODULE_API_NO > 20060613 
-	zend_restore_error_handling(&error_handling TSRMLS_CC);
-#else
-	php_set_error_handling(EH_NORMAL, NULL TSRMLS_CC);
-#endif
-
-	/* php_stream_cast returns warning on some streams but still does not return FAILURE */
-	if (EG(exception)) {
-		return 1;
-	}
-
-	if (type == IMAGICK_WRITE_IMAGE_FILE) {
-		status = MagickWriteImageFile(intern->magick_wand, fp);
-	} else if (type == IMAGICK_WRITE_IMAGES_FILE) {
-		status = MagickWriteImagesFile(intern->magick_wand, fp);
-	} else if (type == IMAGICK_READ_IMAGE_FILE) {		
-		status = MagickReadImageFile(intern->magick_wand, fp);
-	} else if (type == IMAGICK_PING_IMAGE_FILE) {
-		status = MagickPingImageFile(intern->magick_wand, fp);
-	} 
-
-	if (status == MagickFalse) {
-		return 2;
-	}
-	
-	if (filename) {
-		MagickSetImageFilename(intern->magick_wand, filename);
-		IMAGICK_CORRECT_ITERATOR_POSITION(intern);
-	}	
-	
-	return 0;
-	
-return_on_error:
-#if ZEND_MODULE_API_NO > 20060613 
-	zend_restore_error_handling(&error_handling TSRMLS_CC);
-#else
-	php_set_error_handling(EH_NORMAL, NULL TSRMLS_CC);
-#endif
-	if (EG(exception)) {
-		return 1;
-	} else {
-		return 2;
-	}
-}
-
-/*
-	Does the image filename have format in it
-	For example png:/tmp/filename.jpg
-*/
-zend_bool php_imagick_has_format(const char *filename, int filename_len)
-{
-	/* Absolute path wont have the format in it */
-	if (IS_ABSOLUTE_PATH(filename, filename_len)) {
-		return 0;
-	}
-	
-	/* If the path is not absolute, in that case it should have : to indicate the format */
-	while (*filename != '\0') {
-		if (*(filename++) == ':') {
-			return 1;
-		}
-	}
-	/* Not found */
-	return 0;
-}
-
-/*
-	Returns the filename type, following types are recognised:
-	PHP_IMAGICK_FILE_PLAIN		plain filename, no format or page specifiers
-	PHP_IMAGICK_FILE_FORMAT		has format specifier, f.ex png:/tmp/test.jpg
-	PHP_IMAGICK_FILE_URL		is url, http://example.com/test.gif (this also checks that php has wrapper for that url type)
-*/
-
-int php_imagick_filename_type(const char *filename, int filename_len TSRMLS_DC)
-{
-	char *path = NULL;
-	
-	if (IS_ABSOLUTE_PATH(filename, filename_len)) {
-		return PHP_IMAGICK_FILE_PLAIN;
-	}
-	
-	if (php_imagick_has_format(filename, filename_len)) {
-		if (php_stream_locate_url_wrapper(filename, &path, STREAM_LOCATE_WRAPPERS_ONLY TSRMLS_CC)) {
-			return PHP_IMAGICK_FILE_URL;
-		} else {
-			if ((filename_len > 6 && memcmp(filename, "ftp", 3) == 0) ||
-				(filename_len > 7 && memcmp(filename, "http", 4) == 0) ||
-				(filename_len > 8 && memcmp(filename, "https", 5) == 0)) {
-				return PHP_IMAGICK_FILE_URL;		
-			}
-		}
-		return PHP_IMAGICK_FILE_FORMAT;
-	}
-	return PHP_IMAGICK_FILE_PLAIN;
-}
-
-/*
-	Check if the filename specifies a page
-	Something like /tmp/test.pdf[12]
-*/
-zend_bool php_imagick_filename_has_page(const char *filename, int filename_len, int *page)
-{
-	int i;
-	zend_bool has_number = 0;
-	*page = 0;
-
-	for (i = filename_len; i >= 0; i--) {
-		if (i == filename_len) {
-			if (filename[i] != ']') {
-				return 0;
-			}
-		}
-		else {
-			if (filename[i] >= 48 && filename[i] <= 57) {
-				has_number = 1;
-				*page += atoi(&(filename[i]));
-			}
-			else if (has_number && filename[i] == '[') {
-				return 1;
-			}
-			else {
-				return 0;
-			}
-		}	
-	}
-	return 0;
-}
-
-/*
-	Returns an absolute path for the filename and format if there is one associated with the filename
-	This works for PHP_IMAGICK_FILE_PLAIN and PHP_IMAGICK_FILE_FORMAT
-*/
-char *php_imagick_filename_path(const char *filename, int filename_len, char **format, int *page TSRMLS_DC)
-{
-	char *filename_cp, *path;
-	int type;
-	
-	*format = NULL;
-	*page   = -1;
-	
-	filename_cp = estrdup(filename);
-	
-	if (php_imagick_filename_has_page(filename_cp, filename_len, page)) {
-		for (; filename_len >= 0; filename_len--) {
-			if (filename_cp[filename_len] == '[') {
-				filename_cp[filename_len] = '\0';
-				break;
-			}
-		}
-	}
-	
-	if (IS_ABSOLUTE_PATH(filename_cp, filename_len)) {
-		return filename_cp;
-	}
-
-	type = php_imagick_filename_type(filename_cp, filename_len TSRMLS_CC);
-	
-	if (type == PHP_IMAGICK_FILE_PLAIN) {
-		path = expand_filepath(filename_cp, NULL TSRMLS_CC);
-		efree(filename_cp);
-		return path;
-	}
-	else if (type == PHP_IMAGICK_FILE_FORMAT) {
-		
-		char *pch, *last = NULL;
-
-		pch = php_strtok_r(filename_cp, ":", &last);
-
-		if (!pch || !last || (strlen(last) == 0)) {
-			efree(filename_cp);
-			return NULL;
-		}
-
-		/* Store the original format */
-		*format = estrdup(pch);
-		path    = expand_filepath(last, NULL TSRMLS_CC);
-
-		efree(filename_cp);
-		return path;
-	}
-	
-	efree(filename_cp);
-	return NULL;
-}
-
 
 zend_bool php_imagick_validate_map(const char *map TSRMLS_DC)
 {
@@ -403,46 +188,6 @@ int count_occurences_of(char needle, char *haystack TSRMLS_DC)
 	return occurances;
 }
 
-void add_assoc_string_helper(zval *retvalue, char *name, char *key, char *hash_value TSRMLS_DC)
-{
-	char *pch;
-	char *trimmed;
-	zval *array;
-	int width, height;
-	double x, y;
-
-	if (strncmp(hash_value, name, strlen(name)) == 0) {
-		
-		if (strcmp("geometry", key) == 0) {
-
-			MAKE_STD_ZVAL(array);
-			array_init(array);
-			sscanf(hash_value, "%*s %d%*c%d", &width, &height);
-			add_assoc_long(array, "width", width);
-			add_assoc_long(array, "height", height);
-			add_assoc_zval(retvalue, key, array);
-		
-		} else if (strcmp("resolution" , key) == 0) {
-
-			MAKE_STD_ZVAL(array);
-			array_init(array);
-
-			sscanf(hash_value, "%*s %lf%*c%lf", &x, &y);
-			add_assoc_double(array, "x", x);
-			add_assoc_double(array, "y", y);
-			add_assoc_zval(retvalue, key, array);
-		
-		} else {
-
-			pch = strchr(hash_value, ':');
-			pch = strchr(pch + 1, ' ');
-			trimmed = php_trim(pch, strlen(pch), (char *)NULL, 0, NULL, 3 TSRMLS_CC);
-			add_assoc_string(retvalue, key, trimmed, 1);
-			efree(trimmed);
-		}
-	}
-}
-
 double *get_double_array_from_zval(zval *param_array, long *num_elements TSRMLS_DC)
 {
 	zval **ppzval;
@@ -608,21 +353,6 @@ zend_bool crop_thumbnail_image(MagickWand *magick_wand, long desired_width, long
 	return 1;
 }
 
-void deallocate_wands(MagickWand *magick, DrawingWand *draw, PixelWand *pixel TSRMLS_DC)
-{
-	if (magick != (MagickWand *)NULL) {
-		magick = (MagickWand *)DestroyMagickWand(magick);
-	}
-
-	if (draw != (DrawingWand *)NULL) {
-		draw = (DrawingWand *)DestroyDrawingWand(draw);
-	}
-
-	if (pixel != (PixelWand *)NULL) {
-		pixel = (PixelWand *)DestroyPixelWand(pixel);
-	}
-}
-
 void *get_pointinfo_array(zval *coordinate_array, int *num_elements TSRMLS_DC)
 {
 	PointInfo *coordinates;
@@ -721,66 +451,6 @@ void count_pixeliterator_rows(php_imagickpixeliterator_object *internpix TSRMLS_
 }
 #endif
 
-int php_imagick_safe_mode_check(const char *filename TSRMLS_DC)
-{
-	if (PG(safe_mode) && (!php_checkuid_ex(filename, NULL, CHECKUID_CHECK_FILE_AND_DIR, CHECKUID_NO_ERRORS))) {
-		return IMAGICK_READ_WRITE_SAFE_MODE_ERROR;
-	}
-	
-	if (PG(open_basedir) && php_check_open_basedir_ex(filename, 0 TSRMLS_CC)) {
-		return IMAGICK_READ_WRITE_OPEN_BASEDIR_ERROR;
-	}
-
-	return IMAGICK_READ_WRITE_NO_ERROR;
-}
-
-/* type 1 = writeimage, type 2 = writeimages */
-int write_image_from_filename(php_imagick_object *intern, char *filename, zend_bool adjoin, int type TSRMLS_DC)
-{
-	MagickBooleanType status;
-	int rc, page;
-	char *buffer, *path, *format = NULL;
-
-	path = php_imagick_filename_path(filename, strlen(filename), &format, &page TSRMLS_CC);
-	
-	if (!path) {
-		return IMAGICK_READ_WRITE_UNDERLYING_LIBRARY;
-	}
-
-	rc = php_imagick_safe_mode_check(path TSRMLS_CC);
-	if (rc != IMAGICK_READ_WRITE_NO_ERROR) {
-		if (format) {
-			efree(format);
-		}
-		efree(path);
-		return rc;
-	}
-
-	if (format) {
-		(void) spprintf(&buffer, 0, "%s:%s", format, path);
-		efree(format);
-	} else {
-		buffer = estrdup(path);
-	}
-
-	if (type == 1) {
-		status = MagickWriteImage(intern->magick_wand, buffer);
-	} else {
-		status = MagickWriteImages(intern->magick_wand, buffer, adjoin);
-	}
-
-	efree(path);
-	efree(buffer);	
-
-	/* Write succeded ? */
-	if (status == MagickFalse) {
-		return IMAGICK_READ_WRITE_UNDERLYING_LIBRARY;
-	}
-
-	/* All went well it seems */
-	return IMAGICK_READ_WRITE_NO_ERROR;
-}
-
 void initialize_imagick_constants()
 {
 	TSRMLS_FETCH();
