@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 5 / Imagick	                                          |
    +----------------------------------------------------------------------+
-   | Copyright (c) 2006-2009 Mikko Koppanen, Scott MacVicar               |
+   | Copyright (c) 2006-2013 Mikko Koppanen, Scott MacVicar               |
    | Imagemagick (c) ImageMagick Studio LLC                               |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
@@ -21,6 +21,7 @@
 #include "php_imagick.h"
 #include "php_imagick_defs.h"
 #include "php_imagick_macros.h"
+#include "php_imagick_helpers.h"
 
 #if MagickLibVersion > 0x628
 /* {{{ proto bool ImagickDraw::resetvectorgraphics()
@@ -111,6 +112,42 @@ PHP_METHOD(imagickdraw, settextinterwordspacing)
 /* }}} */
 #endif
 
+#if MagickLibVersion > 0x655
+/* {{{ proto bool ImagickDraw::getTextInterlineSpacing()
+	Gets the text interword spacing
+*/
+PHP_METHOD(imagickdraw, gettextinterlinespacing)
+{
+	php_imagickdraw_object *internd;
+
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE) {
+		return;
+	}
+
+	internd = (php_imagickdraw_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
+	RETURN_DOUBLE(DrawGetTextInterlineSpacing(internd->drawing_wand));
+}
+/* }}} */
+
+/* {{{ proto bool ImagickDraw::setTextInterlineSpacing(float spacing)
+	Sets the text interword spacing
+*/
+PHP_METHOD(imagickdraw, settextinterlinespacing)
+{
+	php_imagickdraw_object *internd;
+	double spacing;
+
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "d", &spacing) == FAILURE) {
+		return;
+	}
+
+	internd = (php_imagickdraw_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
+	DrawSetTextInterlineSpacing(internd->drawing_wand, spacing);
+	RETURN_TRUE;
+}
+/* }}} */
+#endif
+
 /* {{{ proto ImagickDraw ImagickDraw::__construct()
    The ImagickDraw constructor
 */
@@ -282,6 +319,44 @@ PHP_METHOD(imagickdraw, setfillcolor)
 }
 /* }}} */
 
+/* {{{ proto bool ImagickDraw::setResolution(float x, float y)
+	Sets the resolution
+*/
+PHP_METHOD(imagickdraw, setresolution)
+{
+	char *density, buf[512];
+	double x, y;
+	php_imagickdraw_object *internd;
+	DrawInfo *draw_info;
+	DrawingWand *d_wand;
+
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "dd", &x, &y) == FAILURE) {
+		return;
+	}
+
+	internd = (php_imagickdraw_object *) zend_object_store_get_object(getThis() TSRMLS_CC);
+
+	(void) snprintf(buf, 512, "%fx%f", x, y);
+	density = AcquireString(buf);
+
+	if (!density) {
+		IMAGICK_THROW_EXCEPTION_WITH_MESSAGE(IMAGICKDRAW_CLASS, "Failed to allocate memory", 2);
+	}
+
+	draw_info          = PeekDrawingWand(internd->drawing_wand);
+	draw_info->density = density;
+	
+	d_wand = (DrawingWand *) DrawAllocateWand(draw_info, NULL);
+	
+	if (!d_wand) {
+		IMAGICK_THROW_EXCEPTION_WITH_MESSAGE(IMAGICKDRAW_CLASS, "Failed to allocate new DrawingWand structure", 2);
+	}
+	
+	IMAGICKDRAW_REPLACE_DRAWINGWAND(internd, d_wand);
+	RETURN_TRUE;
+}
+/* }}} */
+
 /* {{{ proto bool ImagickDraw::setStrokeColor(PixelWand stroke_wand)
 	Sets the color used for stroking object outlines.
 */
@@ -896,11 +971,6 @@ PHP_METHOD(imagickdraw, destroy)
 	}
 
 	ClearDrawingWand(internd->drawing_wand);
-#ifdef Z_SET_REFCOUNT_P
-	Z_SET_REFCOUNT_P(object, 0);
-#else
-	object->refcount = 0;
-#endif
 	RETURN_TRUE;
 }
 /* }}} */
@@ -1090,6 +1160,8 @@ PHP_METHOD(imagickdraw, clone)
 		return;
 	}
 	
+	IMAGICK_METHOD_DEPRECATED("ImagickDraw", "clone");
+	
 	internd = (php_imagickdraw_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
 	tmp_wand = CloneDrawingWand(internd->drawing_wand);
 
