@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 5 / Imagick	                                          |
    +----------------------------------------------------------------------+
-   | Copyright (c) 2006-2009 Mikko Koppanen, Scott MacVicar               |
+   | Copyright (c) 2006-2013 Mikko Koppanen, Scott MacVicar               |
    | Imagemagick (c) ImageMagick Studio LLC                               |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
@@ -99,38 +99,6 @@ typedef struct _php_imagickpixel_object  {
 	int initialized_via_iterator;
 } php_imagickpixel_object;
 
-
-void initialize_imagick_constants();
-void add_assoc_string_helper(zval *retvalue, char *name, char *key, char *hash_value TSRMLS_DC );
-void deallocate_wands(MagickWand *magick, DrawingWand *draw, PixelWand *pixel TSRMLS_DC );
-void *get_pointinfo_array(zval *coordinate_array, int *num_elements TSRMLS_DC);
-#if MagickLibVersion <= 0x628
-void count_pixeliterator_rows(php_imagickpixeliterator_object *internpix TSRMLS_DC );
-#endif
-
-int count_occurences_of(char needle, char *haystack TSRMLS_DC );
-int read_image_into_magickwand(php_imagick_object *intern, int type, char *filename, int filename_len TSRMLS_DC);
-int write_image_from_filename(php_imagick_object *intern, char *filename, zend_bool adjoin, int type TSRMLS_DC);
-int check_configured_font(char *font, int font_len TSRMLS_DC);
-int check_write_access(char *absolute TSRMLS_DC);
-
-MagickBooleanType php_imagick_read_image_using_imagemagick(php_imagick_object *intern, int type, char *filename, int filename_len TSRMLS_DC);
-
-zend_bool php_imagick_thumbnail_dimensions(MagickWand *magick_wand, zend_bool bestfit, long desired_width, long desired_height, long *new_width, long *new_height);
-zend_bool php_imagick_resize_bounding_box(MagickWand *magick_wand, long box_width, long box_height, zend_bool fill);
-
-zend_bool crop_thumbnail_image(MagickWand *magick_wand, long desired_width, long desired_height TSRMLS_DC);
-char *get_pseudo_filename(char* pseudo_string TSRMLS_DC);
-double *get_double_array_from_zval(zval *param_array, long *num_elements TSRMLS_DC);
-long *get_long_array_from_zval(zval *param_array, long *num_elements TSRMLS_DC);
-unsigned char *get_char_array_from_zval(zval *param_array, long *num_elements TSRMLS_DC);
-
-MagickBooleanType php_imagick_progress_monitor(const char *text, const MagickOffsetType offset, const MagickSizeType span, void *client_data);
-int php_imagick_stream_handler(php_imagick_object *intern, php_stream *stream, char *filename, int type TSRMLS_DC);
-zend_bool php_imagick_validate_map(const char *map TSRMLS_DC);
-
-int php_imagick_safe_mode_check(const char *filename TSRMLS_DC);
-
 /* Define some color constants */
 #define IMAGICKCOLORBLACK 11
 #define IMAGICKCOLORBLUE 12
@@ -562,9 +530,14 @@ PHP_METHOD(imagickdraw, settextkerning);
 PHP_METHOD(imagickdraw, gettextinterwordspacing);
 PHP_METHOD(imagickdraw, settextinterwordspacing);
 #endif
+#if MagickLibVersion > 0x655
+PHP_METHOD(imagickdraw, gettextinterlinespacing);
+PHP_METHOD(imagickdraw, settextinterlinespacing);
+#endif
 PHP_METHOD(imagickdraw, __construct);
 PHP_METHOD(imagickdraw, setfillcolor);
 PHP_METHOD(imagickdraw, setfillalpha);
+PHP_METHOD(imagickdraw, setresolution);
 PHP_METHOD(imagickdraw, setstrokecolor);
 PHP_METHOD(imagickdraw, setstrokealpha);
 PHP_METHOD(imagickdraw, setstrokewidth);
